# sample action message to control (start/stop) a generic skill.
# This is for illustration purpose: you probably will want to
# eg pass custom data to configure your skill, or return specific
# values: feel free to modify it as needed.

std_skills/Meta meta
string skill_data
---
std_skills/Result result
string value
---
std_skills/Feedback feedback

